@@ -153,13 +153,13 @@ class Model(AbstractBase):
         )
 
         for person_io in model_io.people:
-            Person.hydrate(person_io, model=model)
+            model += Person.hydrate(person_io)
 
         for software_system_io in model_io.software_systems:
-            SoftwareSystem.hydrate(software_system_io, model=model)
+            model += SoftwareSystem.hydrate(software_system_io)
 
         for deployment_node_io in model_io.deployment_nodes:
-            DeploymentNode.hydrate(deployment_node_io, model=model)
+            model += DeploymentNode.hydrate(deployment_node_io, model=model)
 
         for element in model.get_elements():
             for relationship in element.relationships:
@@ -310,11 +310,8 @@ class Model(AbstractBase):
         """
         if relationship is None:
             relationship = Relationship(**kwargs)
-        # Check
-        if self._add_relationship(relationship, create_implied_relationships):
-            return relationship
-        else:
-            return
+        self._add_relationship(relationship, create_implied_relationships)
+        return relationship
 
     def get_element(self, id: str) -> Optional[Element]:
         """
@@ -368,12 +365,14 @@ class Model(AbstractBase):
         self._elements_by_id[element.id] = element
         element.set_model(self)
         self._id_generator.found(element.id)
+        for child in element.child_elements:
+            self += child
 
     def _add_relationship(
         self, relationship: Relationship, create_implied_relationships: bool
-    ) -> bool:
+    ):
         if relationship in self.get_relationships():
-            return True
+            return
         if not relationship.id:
             relationship.id = self._id_generator.generate_id()
         elif relationship.id in self._elements_by_id:
@@ -393,7 +392,6 @@ class Model(AbstractBase):
 
         if create_implied_relationships:
             self.implied_relationship_strategy(relationship)
-        return True
 
     def _add_relationship_to_internal_structures(self, relationship: Relationship):
         self._relationships_by_id[relationship.id] = relationship
