@@ -16,7 +16,7 @@
 """Provide a software system element model."""
 
 
-from typing import TYPE_CHECKING, Iterable, List, Set
+from typing import Iterable, List, Set
 
 from pydantic import Field
 
@@ -26,10 +26,6 @@ from .static_structure_element import StaticStructureElement, StaticStructureEle
 from .tags import Tags
 
 
-if TYPE_CHECKING:  # pragma: no cover
-    from .model import Model
-
-
 __all__ = ("SoftwareSystem", "SoftwareSystemIO")
 
 
@@ -79,6 +75,11 @@ class SoftwareSystem(StaticStructureElement):
         """Return read-only list of child containers."""
         return list(self._containers)
 
+    @property
+    def child_elements(self) -> Iterable[Container]:
+        """Return child elements (from `Element.children`)."""
+        return self.containers
+
     def add_container(
         self, name: str, description: str = "", technology: str = "", **kwargs
     ) -> Container:
@@ -109,8 +110,9 @@ class SoftwareSystem(StaticStructureElement):
                 f"{container.parent}. Cannot add to {self}."
             )
         self._containers.add(container)
-        model = self.model
-        model += container
+        if self.has_model:
+            model = self.model
+            model += container
         return self
 
     def get_container_with_name(self, name: str) -> Container:
@@ -118,24 +120,17 @@ class SoftwareSystem(StaticStructureElement):
         return next((c for c in self._containers if c.name == name), None)
 
     @classmethod
-    def hydrate(
-        cls, software_system_io: SoftwareSystemIO, model: "Model"
-    ) -> "SoftwareSystem":
-        """Create a new SoftwareSystem instance and hydrate it from its IO.
-
-        This will also automatically register with the model.
-        """
+    def hydrate(cls, software_system_io: SoftwareSystemIO) -> "SoftwareSystem":
+        """Create a new SoftwareSystem instance and hydrate it from its IO."""
         software_system = cls(
             **cls.hydrate_arguments(software_system_io),
             location=software_system_io.location,
         )
-        model += software_system
 
         for container_io in software_system_io.containers:
             software_system += Container.hydrate(
                 container_io,
                 software_system=software_system,
-                model=model,
             )
 
         return software_system
